@@ -45,8 +45,16 @@ fn exprs() -> impl Fold {
 }
 
 /// Compiles es2015 to es5.
+///
+/// # Parameters
+///
+/// ## `unresolved_mark`
+///
+/// Used to generate `require` calls.
+/// See the documentation of [regenerator](self::regenerator::regenerator) for
+/// more details.
 #[tracing::instrument(level = "info", skip_all)]
-pub fn es2015<C>(global_mark: Mark, comments: Option<C>, c: Config) -> impl Fold
+pub fn es2015<C>(unresolved_mark: Mark, comments: Option<C>, c: Config) -> impl Fold
 where
     C: Comments,
 {
@@ -76,7 +84,7 @@ where
         computed_properties(c.computed_props),
         destructuring(c.destructuring),
         block_scoping(),
-        regenerator(c.regenerator, global_mark),
+        regenerator(c.regenerator, unresolved_mark),
     )
 }
 
@@ -114,7 +122,7 @@ pub struct Config {
 #[cfg(test)]
 mod tests {
     use swc_common::Mark;
-    use swc_ecma_transforms_base::resolver::resolver;
+    use swc_ecma_transforms_base::resolver;
     use swc_ecma_transforms_testing::{test, test_exec};
 
     use super::*;
@@ -207,7 +215,10 @@ export default function fn1() {
 
     test!(
         ::swc_ecma_parser::Syntax::default(),
-        |_| chain!(block_scoped_functions(), resolver(),),
+        |_| chain!(
+            block_scoped_functions(),
+            resolver(Mark::new(), Mark::new(), false)
+        ),
         issue_271,
         "
 function foo(scope) {
